@@ -18,9 +18,11 @@
 # 3.3            | pip     | 10.0.1       |
 # 3.4            | pip     | 19.1.1       |
 
+import os.path as osp
+
 # Things that change more often go here.
 copyright = """
-Copyright (C) 2015-2020 Rocky Bernstein <rb@dustyfeet.com>.
+Copyright (C) 2015-2020, 2023-204 Rocky Bernstein <rb@dustyfeet.com>.
 """
 
 classifiers = [
@@ -29,11 +31,14 @@ classifiers = [
     "Intended Audience :: Developers",
     "Operating System :: OS Independent",
     "Programming Language :: Python",
+    "Programming Language :: Python :: 2",
     "Programming Language :: Python :: 2.4",
     "Programming Language :: Python :: 2.5",
     "Programming Language :: Python :: 2.6",
     "Programming Language :: Python :: 2.7",
     "Programming Language :: Python :: 3",
+    "Programming Language :: Python :: 3.1",
+    "Programming Language :: Python :: 3.2",
     "Programming Language :: Python :: 3.3",
     "Programming Language :: Python :: 3.4",
     "Programming Language :: Python :: 3.5",
@@ -41,6 +46,10 @@ classifiers = [
     "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
+    "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: 3.11",
+    "Programming Language :: Python :: 3.12",
+    "Programming Language :: Python :: Implementation :: PyPy",
     "Topic :: Software Development :: Debuggers",
     "Topic :: Software Development :: Libraries :: Python Modules",
 ]
@@ -66,7 +75,7 @@ license = "GPL-2.0"
 mailing_list = "python-debugger@googlegroups.com"
 modname = "xdis"
 packages = ["xdis"]
-py_modules = None
+python_requires = ">=3.6,<3.13"
 # setup_requires     = ['pytest-runner']
 scripts = ["bin/pydisasm.py"]
 short_desc = "Python cross-version byte-code disassembler and marshal routines"
@@ -76,8 +85,6 @@ web = "https://github.com/rocky/python-xdis/"
 # tracebacks in zip files are funky and not debuggable
 zip_safe = True
 
-import os.path as osp
-
 
 def get_srcdir():
     filename = osp.normcase(osp.dirname(osp.abspath(__file__)))
